==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/sonnet/misc/settings.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; -*-
/**
 * settings.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_SETTINGS_H
#define KSPELL_SETTINGS_H

#include <qstringlist.h>
#include <qstring.h>
#include <kdelibs_export.h>
#include <kconfig.h>

namespace KSpell2
{
    class Loader;

    class KSPELL2_EXPORT Settings
    {
    public:
        ~Settings();

        void setDefaultLanguage( const QString& lang );
        QString defaultLanguage() const;

        void setDefaultClient( const QString& client );
        QString defaultClient() const;

        void setCheckUppercase( bool );
        bool checkUppercase() const;

        void setSkipRunTogether( bool );
        bool skipRunTogether() const;

        void setBackgroundCheckerEnabled( bool );
        bool backgroundCheckerEnabled() const;

        void setCurrentIgnoreList( const QStringList& ignores );
        void addWordToIgnore( const QString& word );
        QStringList currentIgnoreList() const;
        bool ignore( const QString& word );

        void save();

        KSharedConfig *sharedConfig() const;

        int disablePercentageWordError() const;
        int disableWordErrorCount() const;


    private:
        void loadConfig();
        void readIgnoreList();
        void setQuietIgnoreList( const QStringList& ignores );

    private:
        friend class Loader;
        Settings( Loader *loader, KSharedConfig::Ptr config );
    private:
        class Private;
        Private* const d;
    };
}

#endif

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/sonnet/misc/settings.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; -*-
/**
 * settings.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_SETTINGS_H
#define KSPELL_SETTINGS_H

#include <qstringlist.h>
#include <qstring.h>
#include <kdelibs_export.h>
#include <kconfig.h>

namespace KSpell2
{
    class Loader;

    class SONNETCORE_EXPORT Settings
    {
    public:
        ~Settings();

        void setDefaultLanguage( const QString& lang );
        QString defaultLanguage() const;

        void setDefaultClient( const QString& client );
        QString defaultClient() const;

        void setCheckUppercase( bool );
        bool checkUppercase() const;

        void setSkipRunTogether( bool );
        bool skipRunTogether() const;

        void setBackgroundCheckerEnabled( bool );
        bool backgroundCheckerEnabled() const;

        void setCurrentIgnoreList( const QStringList& ignores );
        void addWordToIgnore( const QString& word );
        QStringList currentIgnoreList() const;
        bool ignore( const QString& word );

        void save();

        KSharedConfig *sharedConfig() const;

        int disablePercentageWordError() const;
        int disableWordErrorCount() const;


    private:
        void loadConfig();
        void readIgnoreList();
        void setQuietIgnoreList( const QStringList& ignores );

    private:
        friend class Loader;
        Settings( Loader *loader, KSharedConfig::Ptr config );
    private:
        class Private;
        Private* const d;
    };
}

#endif
